Get average estimated (continuous ranked probability score) for the forecast; the score at each time point is estimated through numerical integration. CRPS characterizes calibration and sharpness together
1 |
ts |
A ts_forecast object |
tel |
A vector of the telemetry values |
normalize.by |
(optional) A normalization factor, either a scalar or vector |
... |
optional arguments to equalize_telemetry_forecast_length |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.