get_discrete_continuous_model: Get the discrete and continuous components of the weighted...

Description Usage Arguments Value

View source: R/prob_forecast.R

Description

Get the discrete and continuous components of the weighted mixture model as well as the member-specific components

Usage

1
get_discrete_continuous_model(x, xseq = seq(0, 1, 1e-04), discrete = F)

Arguments

x

fc_bma object

xseq

Vector of x values in [0,1] to evaluate

discrete

Boolean of whether to return density with a discrete component (approximate) or with the continuous estimation (congruent with CDF)

Value

A list of the discrete components (PoC) and continuous density (pdf) and distribution (cdf) for each member


kdayday/forecasting documentation built on Oct. 7, 2020, 7:16 p.m.