plot_pdf.fc_vine: Plot probabilistic forecast's estimated pdf (with kde) Note...

Description Usage Arguments

View source: R/prob_forecast.R

Description

Plot probabilistic forecast's estimated pdf (with kde) Note that CVaR and VaR, while represented on the graph, are calculated directly from sampled data rather than estimated from the kde results.

Usage

1
2
## S3 method for class 'fc_vine'
plot_pdf(x, cvar = FALSE, epsilon = c(0.05, 0.95))

Arguments

x

fc_vine object


kdayday/forecasting documentation built on Oct. 7, 2020, 7:16 p.m.