Proper Scoring Rules for Discretized Log-Normal Forecasts
Source:R/scores_lnorm_discrete.R
scores_lnorm_discrete.RdCompute scores for discretized log-normal forecasts. The function is vectorized and preserves the dimension of the input.
Usage
scores_lnorm_discrete(x, meanlog, sdlog, which = c("dss", "logs"))Arguments
- x
the observed counts.
- meanlog, sdlog
parameters of the log-normal distribution, i.e., mean and standard deviation of the distribution on the log scale.
- which
a character vector specifying which scoring rules to apply. The Dawid-Sebastiani score (
"dss") and the logarithmic score ("logs") are available and both computed by default.