Description Usage Arguments Value
View source: R/prob_forecast.R
Get the discrete and continuous components of the weighted mixture model as well as the member-specific components
1 | get_discrete_continuous_model(x, xseq = seq(0, 1, 1e-04), discrete = F)
|
x |
fc_bma object |
xseq |
Vector of x values in [0,1] to evaluate |
discrete |
Boolean of whether to return density with a discrete component (approximate) or with the continuous estimation (congruent with CDF) |
A list of the discrete components (PoC) and continuous density (pdf) and distribution (cdf) for each member
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.