View source: R/prob_forecast.R
Plot probabilistic forecast's estimated pdf (with kde) Note that CVaR and VaR, while represented on the graph, are calculated directly from sampled data rather than estimated from the kde results.
1 2 |
x |
fc_vine object |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.